<?php
/* --------------------------------------------------------------
   AfterbuyOrderPaymentInfoMapper.php 2022-10-15
   Gambio GmbH
   http://www.gambio.de
   Copyright (c) 2022 Gambio GmbH
   Released under the GNU General Public License (Version 2)
   [http://www.gnu.org/licenses/gpl-2.0.html]
   --------------------------------------------------------------
*/

declare(strict_types=1);

namespace GXModules\Gambio\Afterbuy\OrderExport\App\Data\AfterbuyOrder;

use GXModules\Gambio\Afterbuy\OrderExport\Model\Request\PaymentInfo;

/**
 * Class AfterbuyOrderPaymentInfoMapper
 *
 * @package GXModules\Gambio\Afterbuy\OrderExport\App\Data\AfterbuyOrder
 */
class AfterbuyOrderPaymentInfoMapper
{
    private const FIELD_PAYMENT_METHOD = 'payment_method';
    
    private AfterbuyOrderPaymentInfoReader $reader;
    
    
    /**
     * AfterbuyOrderPaymentInfoMapper constructor.
     *
     * @param AfterbuyOrderPaymentInfoReader $reader
     */
    public function __construct(AfterbuyOrderPaymentInfoReader $reader)
    {
        $this->reader = $reader;
    }
    
    
    /**
     * Maps order data to payment information.
     *
     * @param array $data
     *
     * @return PaymentInfo
     */
    public function map(array $data): PaymentInfo
    {
        $paymentClass = $data[self::FIELD_PAYMENT_METHOD];
        
        $paymentMethod         = $this->reader->getPaymentMethod($paymentClass);
        $paymentDate           = new \DateTimeImmutable(); // Todo: Check if somewhere available
        $alreadyPaid           = $this->reader->getAlreadyPaid($data);
        $paymentAdditionalCost = null; // Todo: Check if somewhere available
        $sendPaymentMail       = null; // Todo: Check if somewhere available
        
        return new PaymentInfo($paymentMethod, $paymentDate, $alreadyPaid, $paymentAdditionalCost, $sendPaymentMail);
    }
}