<?php
/* --------------------------------------------------------------
   AfterbuyOrderRepository.php 2022-10-14
   Gambio GmbH
   http://www.gambio.de
   Copyright (c) 2022 Gambio GmbH
   Released under the GNU General Public License (Version 2)
   [http://www.gnu.org/licenses/gpl-2.0.html]
   --------------------------------------------------------------
*/

declare(strict_types=1);

namespace GXModules\Gambio\Afterbuy\OrderExport\App\Data\AfterbuyOrder;

use GXModules\Gambio\Afterbuy\OrderExport\Model\OrderIds;
use GXModules\Gambio\Afterbuy\OrderExport\Model\Request\BuyerInfo;
use GXModules\Gambio\Afterbuy\OrderExport\Model\Request\Order;
use GXModules\Gambio\Afterbuy\OrderExport\Model\Request\Orders;
use GXModules\Gambio\Afterbuy\OrderExport\Model\Request\PaymentInfo;
use GXModules\Gambio\Afterbuy\OrderExport\Model\Request\ShippingAddress;
use GXModules\Gambio\Afterbuy\OrderExport\Model\Request\ShippingInfo;

/**
 * Class AfterbuyOrderRepository
 *
 * @package GXModules\Gambio\Afterbuy\OrderExport\App\Data
 */
class AfterbuyOrderRepository
{
    private AfterbuyOrderReader                $orderReader;
    private AfterbuyOrderShippingAddressMapper $shippingAddressMapper;
    private AfterbuyOrderPaymentInfoMapper     $paymentInfoMapper;
    private AfterbuyOrderShippingInfoMapper    $shippingInfoMapper;
    
    
    /**
     * AfterbuyOrderRepository constructor.
     *
     * @param AfterbuyOrderReader                $orderReader
     * @param AfterbuyOrderShippingAddressMapper $shippingAddressMapper
     * @param AfterbuyOrderPaymentInfoMapper     $paymentInfoMapper
     * @param AfterbuyOrderShippingInfoMapper    $shippingInfoMapper
     */
    public function __construct(
        AfterbuyOrderReader                $orderReader,
        AfterbuyOrderShippingAddressMapper $shippingAddressMapper,
        AfterbuyOrderPaymentInfoMapper     $paymentInfoMapper,
        AfterbuyOrderShippingInfoMapper    $shippingInfoMapper
    ) {
        $this->orderReader           = $orderReader;
        $this->shippingAddressMapper = $shippingAddressMapper;
        $this->paymentInfoMapper     = $paymentInfoMapper;
        $this->shippingInfoMapper    = $shippingInfoMapper;
    }
    
    
    public function getOrders(OrderIds $orderIds): Orders
    {
        $orders    = [];
        $orderData = $this->orderReader->getOrdersData($orderIds);
        foreach ($orderData as $data) {
            $shippingAddress = $this->shippingAddressMapper->map($data);
            
            $orderId = (int)$data['afterbuy_order_id'];
            // Todo: Check where value is available .. maybe for each order item?
            $itemId       = (int)$data['orders_id'];
            $buyerInfo    = new BuyerInfo($shippingAddress);
            $paymentInfo  = $this->paymentInfoMapper->map($data);
            $shippingInfo = $this->shippingInfoMapper->map($data);
            
            $order    = new Order($orderId,
                                  $itemId,
                                  $buyerInfo,
                                  $paymentInfo,
                                  $shippingInfo,
                // Todo: Check where value is available
                                  $additionalInfo = null,
                // Todo: Check where value is available
                                  $mailDate = null,
                // Todo: Check where value is available
                                  $reminderMailDate = null,
                // Todo: Check where value is available
                                  $userComment = null,
                // Todo: Check where value is available
                                  $orderMemo = null,
                // Todo: Check where value is available
                                  $invoiceMemo = null,
                // Todo: Check where value is available
                                  $invoiceNumber = null,
                // Todo: Check where value is available
                                  $orderExported = null,
                // Todo: Check where value is available
                                  $invoiceDate = null,
                // Todo: Check where value is available
                                  $hideOrder = null,
                // Todo: Check where value is available
                                  $reminderDateOne = null,
                // Todo: Check where value is available
                                  $reminderDateTwo = null,
                // Todo: Check where value is available
                                  $feedbackDate = null,
                // Todo: Check where value is available
                                  $xmlDate = null);
            $orders[] = $order;
        }
        
        // dummy return value
        return new Orders(...$orders);
    }
}