<?php
/* --------------------------------------------------------------
   AfterbuyOrderShippingInfoMapper.php 2022-10-15
   Gambio GmbH
   http://www.gambio.de
   Copyright (c) 2022 Gambio GmbH
   Released under the GNU General Public License (Version 2)
   [http://www.gnu.org/licenses/gpl-2.0.html]
   --------------------------------------------------------------
*/

declare(strict_types=1);

namespace GXModules\Gambio\Afterbuy\OrderExport\App\Data\AfterbuyOrder;

use GXModules\Gambio\Afterbuy\OrderExport\Model\Request\ShippingInfo;

/**
 * Class AfterbuyOrderShippingInfoMapper
 *
 * @package GXModules\Gambio\Afterbuy\OrderExport\App\Data\AfterbuyOrder
 */
class AfterbuyOrderShippingInfoMapper
{
    private const FIELD_ORDER_SHIPPING_METHOD = 'shipping_method';
    private const FIELD_ORDER_SHIPPING_CLASS  = 'shipping_class';
    
    private AfterbuyOrderShippingReader $reader;
    
    
    /**
     * AfterbuyOrderShippingInfoMapper constructor.
     *
     * @param AfterbuyOrderShippingReader $reader
     */
    public function __construct(AfterbuyOrderShippingReader $reader)
    {
        $this->reader = $reader;
    }
    
    
    public function map(array $data): ShippingInfo
    {
        $shippingMethod = $this->getShippingMethod($data);
        $shippingGroup  = 'standard';
        $shippingCost   = $this->reader->getShippingCost($data);
        $deliveryDate   = new \DateTimeImmutable(); // Todo: Check where value is available
        
        return new ShippingInfo($shippingMethod,
                                $shippingGroup,
                                $deliveryDate,
                                $shippingCost,
            // Todo: Check where value is available
                                $sendShippingMail = null,
            // Todo: Check where value is available
                                $shippingReturnMethod = null,
            // Todo: Check where value is available
                                $ebayShippingCost = null);
    }
    
    
    /**
     * Returns the shipping method from the given data.
     *
     * @param array $data
     *
     * @return string
     */
    private function getShippingMethod(array $data): string
    {
        $shippingMethod = $data[self::FIELD_ORDER_SHIPPING_METHOD] ?? '';
        if (empty($shippingMethod)) {
            $shippingClass = $data[self::FIELD_ORDER_SHIPPING_CLASS] ?? '';
            
            return $this->reader->getShippingMethodFromClass($shippingClass);
        }
        
        return $shippingMethod;
    }
}