<?php
/* --------------------------------------------------------------
   AfterbuyOrderShippingReader.php 2022-10-15
   Gambio GmbH
   http://www.gambio.de
   Copyright (c) 2022 Gambio GmbH
   Released under the GNU General Public License (Version 2)
   [http://www.gnu.org/licenses/gpl-2.0.html]
   --------------------------------------------------------------
*/

declare(strict_types=1);

namespace GXModules\Gambio\Afterbuy\OrderExport\App\Data\AfterbuyOrder;

use Gambio\Core\Configuration\Services\ConfigurationFinder;
use GXModules\Gambio\Afterbuy\OrderExport\Exceptions\AfterbuyOrderTotalDataNotFoundException;

/**
 * Class AfterbuyOrderShippingReader
 *
 * @package GXModules\Gambio\Afterbuy\OrderExport\App\Data\AfterbuyOrder
 */
class AfterbuyOrderShippingReader
{
    private const CONFIG_SCAFFOLD = 'configuration/MODULE_SHIPPING_%s_ALIAS';
    
    private ConfigurationFinder      $configurationFinder;
    private AfterbuyOrderTotalReader $orderTotalReader;
    
    
    /**
     * AfterbuyOrderShippingReader constructor.
     *
     * @param ConfigurationFinder      $configurationFinder
     * @param AfterbuyOrderTotalReader $orderTotalReader
     */
    public function __construct(ConfigurationFinder $configurationFinder, AfterbuyOrderTotalReader $orderTotalReader)
    {
        $this->configurationFinder = $configurationFinder;
        $this->orderTotalReader    = $orderTotalReader;
    }
    
    
    /**
     * Tries to get the shipping method name from the configuration.
     * Returns the $shippingClass if nothing was found.
     *
     * @param string $shippingClass
     *
     * @return string
     */
    public function getShippingMethodFromClass(string $shippingClass): string
    {
        $shippingClassArray = explode('_', $shippingClass);
        if (count($shippingClassArray) === 2) {
            $shippingClass = (string)array_pop($shippingClassArray);
        }
        $shippingClass = strtoupper($shippingClass);
        
        $key    = sprintf(self::CONFIG_SCAFFOLD, $shippingClass);
        $config = $this->configurationFinder->get($key);
        
        return $config ?? $shippingClass;
    }
    
    
    /**
     * Returns shipping cost for order.
     *
     * @param array $data
     *
     * @return float|null
     */
    public function getShippingCost(array $data): ?float
    {
        $orderId = (int)$data['orders_id'];
        try {
            $orderTotalData = $this->orderTotalReader->fetchOrderTotalsByOrderId($orderId);
            if (array_key_exists('ot_shipping', $orderTotalData)) {
                return (float)$orderTotalData['ot_shipping'];
            }
        } catch (AfterbuyOrderTotalDataNotFoundException $e) {
        }
        
        return null;
    }
}